summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/notation/TrackHeader.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/editors/notation/TrackHeader.h')
-rw-r--r--src/gui/editors/notation/TrackHeader.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/gui/editors/notation/TrackHeader.h b/src/gui/editors/notation/TrackHeader.h
index 1cb4f1e..0b8a0a6 100644
--- a/src/gui/editors/notation/TrackHeader.h
+++ b/src/gui/editors/notation/TrackHeader.h
@@ -50,16 +50,17 @@ class NotationView;
class ColourMap;
class Segment;
-class TrackHeader : public QLabel
+class TrackHeader : public TQLabel
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Create a new track header for track of id trackId.
* *parent is the parent widget, height the height of staff and
* ypos is the staff y position on canvas.
*/
- TrackHeader(TQWidget *parent, TrackId trackId, int height, int ypos);
+ TrackHeader(TQWidget *tqparent, TrackId trackId, int height, int ypos);
/**
* Draw a blue line around header when current is true
@@ -168,7 +169,7 @@ private :
void transposeValueToName(int transpose, TQString &transposeName);
- // Status bits
+ // tqStatus bits
static const int SEGMENT_HERE;
static const int SUPERIMPOSED_SEGMENTS;
static const int INCONSISTENT_CLEFS;
@@ -50,16 +50,17 @@ class NotationView;
/**
* Create a new track header for track of id trackId.
- * *parent is the parent widget, height the height of staff and
+ * *tqparent is the tqparent widget, height the height of staff and
* ypos is the staff y position on canvas.
*/